@@ -1,5 +1,4 @@
 qt_ <-
-function (p, df, mean, sd) 
-{
+  function(p, df, mean, sd) {
     sd * qt(p, df, ncp = 0) + mean
-}
+  }
