@@ -1,5 +1,4 @@
 rhalfcauchy <-
-function (n, location = 0, scale = 1) 
-{
+  function(n, location = 0, scale = 1) {
     abs(rcauchy(n, location, scale))
-}
+  }
