@@ -1,5 +1,4 @@
 rhalfnorm <-
-function (n, mean = 0, sd = 1) 
-{
+  function(n, mean = 0, sd = 1) {
     abs(rnorm(n, mean, sd))
-}
+  }
