@@ -1,5 +1,4 @@
 rt_ <-
-function (n, df, mean, sd) 
-{
+  function(n, df, mean, sd) {
     mean + sd * rt(n, df, ncp = 0)
-}
+  }
